==> vmaid-1.8.1.tar.gz: vmaid-1.8.1/src/conf.c <==
/*
    Video maid
    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#include <gdk/gdkkeysyms.h>
#include "conf.h"


/******************************************************************************
*                                                                             *
* ؿ                                                                  *
*                                                                             *
******************************************************************************/
static gint width,height;
static GtkWidget *button0,*check0,*check1,*spin0,*spin1,*spin2;
static GtkWidget *radio0,*radio1,*radio2,*radio3;


/* OKܥɽ */
#define conf_dialog_toggled conf_dialog_changed
static void conf_dialog_changed(GtkWidget *widget,gpointer user_data)
{
	gint value0,value1,value2;

	value0=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin0));
	value1=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin1));
	value2=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin2));
	gtk_widget_set_sensitive(button0,0<=value0 && value0<=10
				&& 0<value1 && value1<=width && 0<value2 && value2<=height);
}


/* OKܥ󤬲줿 */
static void conf_dialog_clicked(GtkWidget *widget,GtkWidget *dialog)
{
	gint i;
	GList *glist;
	GtkWidget *sub_menu;

	history=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin0));
	newfile=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check0));
	second=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check1));
	def_width=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin1));
	def_height=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin2));
	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio0)))
		n_pos=GTK_POS_TOP;
	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio1)))
		n_pos=GTK_POS_LEFT;
	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio2)))
		n_pos=GTK_POS_RIGHT;
	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio3)))
		n_pos=GTK_POS_BOTTOM;
	gtk_widget_destroy(dialog);
	/*  */
	sub_menu=gtk_item_factory_get_widget(item_factory_menu,
														"<main>/ե(F)");
	glist=gtk_container_children(GTK_CONTAINER(sub_menu));
	for (i=g_list_length(glist)-3;i>history-(history==0)+MENUFILE-2;i--)
		gtk_container_remove(GTK_CONTAINER(sub_menu),g_list_nth_data(glist,i));
	g_list_free(glist);
	/* ΡȤΰ */
	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(notebook),n_pos);
}


/* ԥܥǥ꥿󤬲줿 */
static void conf_dialog_activate(GtkWidget *widget,GtkWidget *dialog)
{
	gint value0,value1,value2;

	value0=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin0));
	value1=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin1));
	value2=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin2));
	if (0<=value0 && value0<=10
					&& 0<value1 && value1<=width && 0<value2 && value2<=height)
		conf_dialog_clicked(widget,dialog);
}


/* ESC줿 */
static gboolean conf_dialog_key_press(GtkWidget *widget,GdkEventKey *event,
															gpointer user_data)
{
	if (event->keyval==GDK_Escape)
		gtk_widget_destroy(widget);
	return FALSE;
}


void conf_dialog(void)
{
	guint key;
	GtkAccelGroup *accel;
	GtkWidget *dialog,*button1,*label0,*label1,*label2;
	GtkWidget *frame0,*frame1,*hbox0,*hbox1,*vbox;

	width=gdk_screen_width();
	height=gdk_screen_height();

	/* ᥤ󥦥ɥ */
	dialog=gtk_window_new(GTK_WINDOW_DIALOG);
	gtk_window_set_title(GTK_WINDOW(dialog),_(""));
	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
								GTK_SIGNAL_FUNC(conf_dialog_key_press),NULL);
	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
	/* 졼 */
	accel=gtk_accel_group_new();
	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
	/* ܥ */
	button0=gtk_button_new_with_label(_("λ"));
	button1=gtk_button_new_with_label(_(""));
	gtk_signal_connect(GTK_OBJECT(button0),"clicked",
												conf_dialog_clicked,dialog);
	gtk_signal_connect_object(GTK_OBJECT(button1),"clicked",
										gtk_widget_destroy,GTK_OBJECT(dialog));
	GTK_WIDGET_SET_FLAGS(button0,GTK_CAN_DEFAULT);
	GTK_WIDGET_SET_FLAGS(button1,GTK_CAN_DEFAULT);
	/* åܥ */
	check0=gtk_check_button_new_with_label(NULL);
	check1=gtk_check_button_new_with_label(NULL);
	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check0)->child),
												_("ե򳫤(_N)"));
	gtk_widget_add_accelerator(check0,"clicked",accel,key,GDK_MOD1_MASK,0);
	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check1)->child),
												_("ɥ򳫤(_O)"));
	gtk_widget_add_accelerator(check1,"clicked",accel,key,GDK_MOD1_MASK,0);
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check0),newfile);
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check1),second);
	gtk_signal_connect(GTK_OBJECT(check0),"toggled",conf_dialog_toggled,NULL);
	gtk_signal_connect(GTK_OBJECT(check1),"toggled",conf_dialog_toggled,NULL);
	/* ԥܥ */
	spin0=gtk_spin_button_new(
			GTK_ADJUSTMENT(gtk_adjustment_new(history,0,10,1,5,0)),0,0);
	spin1=gtk_spin_button_new(
			GTK_ADJUSTMENT(gtk_adjustment_new(def_width,0,width,1,5,0)),0,0);
	spin2=gtk_spin_button_new(
			GTK_ADJUSTMENT(gtk_adjustment_new(def_height,0,height,1,5,0)),0,0);
	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin0),TRUE);
	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin1),TRUE);
	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin2),TRUE);
	gtk_spin_button_set_shadow_type(GTK_SPIN_BUTTON(spin0),GTK_SHADOW_IN);
	gtk_spin_button_set_shadow_type(GTK_SPIN_BUTTON(spin1),GTK_SHADOW_IN);
	gtk_spin_button_set_shadow_type(GTK_SPIN_BUTTON(spin2),GTK_SHADOW_IN);
	gtk_signal_connect(GTK_OBJECT(spin0),"activate",
												conf_dialog_activate,dialog);
	gtk_signal_connect(GTK_OBJECT(spin1),"activate",
												conf_dialog_activate,dialog);
	gtk_signal_connect(GTK_OBJECT(spin2),"activate",
												conf_dialog_activate,dialog);
	gtk_signal_connect(GTK_OBJECT(spin0),"changed",conf_dialog_changed,NULL);
	gtk_signal_connect(GTK_OBJECT(spin1),"changed",conf_dialog_changed,NULL);
	gtk_signal_connect(GTK_OBJECT(spin2),"changed",conf_dialog_changed,NULL);
	/* ٥ */
	label0=gtk_label_new(NULL);
	label1=gtk_label_new(NULL);
	label2=gtk_label_new(NULL);
	key=gtk_label_parse_uline(GTK_LABEL(label0),_("ե(_I)"));
	gtk_widget_add_accelerator(spin0,"grab-focus",accel,key,GDK_MOD1_MASK,0);
	key=gtk_label_parse_uline(GTK_LABEL(label1),_("(_W)"));
	gtk_widget_add_accelerator(spin1,"grab-focus",accel,key,GDK_MOD1_MASK,0);
	key=gtk_label_parse_uline(GTK_LABEL(label2),_("⤵(_H)"));
	gtk_widget_add_accelerator(spin2,"grab-focus",accel,key,GDK_MOD1_MASK,0);
	/* 饸ܥ */
	radio0=gtk_radio_button_new_with_label(NULL,NULL);
	radio1=gtk_radio_button_new_with_label_from_widget(
												GTK_RADIO_BUTTON(radio0),NULL);
	radio2=gtk_radio_button_new_with_label_from_widget(
												GTK_RADIO_BUTTON(radio1),NULL);
	radio3=gtk_radio_button_new_with_label_from_widget(
												GTK_RADIO_BUTTON(radio2),NULL);
	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio0)->child),_("(_T)"));
	gtk_widget_add_accelerator(radio0,"clicked",accel,key,GDK_MOD1_MASK,0);
	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio1)->child),_("(_L)"));
	gtk_widget_add_accelerator(radio1,"clicked",accel,key,GDK_MOD1_MASK,0);
	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio2)->child),_("(_R)"));
	gtk_widget_add_accelerator(radio2,"clicked",accel,key,GDK_MOD1_MASK,0);
	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio3)->child),_("(_B)"));
	gtk_widget_add_accelerator(radio3,"clicked",accel,key,GDK_MOD1_MASK,0);
	switch (n_pos) {
		case GTK_POS_TOP:	gtk_toggle_button_set_active(
										GTK_TOGGLE_BUTTON(radio0),TRUE);break;
		case GTK_POS_LEFT:	gtk_toggle_button_set_active(
										GTK_TOGGLE_BUTTON(radio1),TRUE);break;
		case GTK_POS_RIGHT:	gtk_toggle_button_set_active(
										GTK_TOGGLE_BUTTON(radio2),TRUE);break;
		case GTK_POS_BOTTOM:gtk_toggle_button_set_active(
										GTK_TOGGLE_BUTTON(radio3),TRUE);
	}
	gtk_signal_connect(GTK_OBJECT(radio0),"toggled",conf_dialog_toggled,NULL);
	gtk_signal_connect(GTK_OBJECT(radio1),"toggled",conf_dialog_toggled,NULL);
	gtk_signal_connect(GTK_OBJECT(radio2),"toggled",conf_dialog_toggled,NULL);
	gtk_signal_connect(GTK_OBJECT(radio3),"toggled",conf_dialog_toggled,NULL);
	/* ե졼ȥܥå */
	frame0=gtk_frame_new(_("ɥΥ"));
	hbox0=gtk_hbox_new(FALSE,8);
	gtk_container_set_border_width(GTK_CONTAINER(hbox0),8);
	hbox1=gtk_hbox_new(FALSE,0);
	gtk_box_pack_start(GTK_BOX(hbox1),label1,FALSE,FALSE,0);
	gtk_box_pack_start(GTK_BOX(hbox1),spin1,TRUE,TRUE,0);
	gtk_box_pack_start(GTK_BOX(hbox0),hbox1,TRUE,TRUE,0);
	hbox1=gtk_hbox_new(FALSE,0);
	gtk_box_pack_start(GTK_BOX(hbox1),label2,FALSE,FALSE,0);
	gtk_box_pack_start(GTK_BOX(hbox1),spin2,TRUE,TRUE,0);
	gtk_box_pack_start(GTK_BOX(hbox0),hbox1,TRUE,TRUE,0);
	gtk_container_add(GTK_CONTAINER(frame0),hbox0);

	frame1=gtk_frame_new(_("֤ΰ"));
	vbox=gtk_vbox_new(FALSE,8);
	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
	hbox0=gtk_hbox_new(FALSE,8);
	gtk_box_pack_start(GTK_BOX(hbox0),radio0,TRUE,FALSE,0);
	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,0);
	hbox0=gtk_hbox_new(FALSE,8);
	gtk_box_pack_start(GTK_BOX(hbox0),radio1,FALSE,FALSE,0);
	gtk_box_pack_end(GTK_BOX(hbox0),radio2,FALSE,FALSE,0);
	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,0);
	hbox0=gtk_hbox_new(FALSE,0);
	gtk_box_pack_start(GTK_BOX(hbox0),radio3,TRUE,FALSE,0);
	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,0);
	gtk_container_add(GTK_CONTAINER(frame1),vbox);

	vbox=gtk_vbox_new(FALSE,8);
	hbox0=gtk_hbox_new(FALSE,0);
	gtk_box_pack_start(GTK_BOX(hbox0),label0,FALSE,FALSE,0);
	gtk_box_pack_start(GTK_BOX(hbox0),spin0,TRUE,TRUE,0);
	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,0);
	gtk_box_pack_start(GTK_BOX(vbox),check0,FALSE,FALSE,0);
	gtk_box_pack_start(GTK_BOX(vbox),check1,FALSE,FALSE,0);
	gtk_box_pack_start(GTK_BOX(vbox),frame0,FALSE,FALSE,0);

	hbox0=gtk_hbox_new(FALSE,8);
	gtk_box_pack_start(GTK_BOX(hbox0),vbox,TRUE,TRUE,0);
	gtk_box_pack_start(GTK_BOX(hbox0),frame1,TRUE,TRUE,0);

	vbox=gtk_vbox_new(FALSE,8);
	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
	gtk_box_pack_start(GTK_BOX(vbox),hbox0,TRUE,TRUE,0);
	hbox0=gtk_hbox_new(FALSE,8);
	gtk_box_pack_end(GTK_BOX(hbox0),button1,FALSE,FALSE,0);
	gtk_box_pack_end(GTK_BOX(hbox0),button0,FALSE,FALSE,0);
	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,0);
	gtk_container_add(GTK_CONTAINER(dialog),vbox);

	/* ɽ */
	gtk_widget_set_sensitive(button0,FALSE);
	gtk_widget_grab_focus(button1);

	gtk_window_set_policy(GTK_WINDOW(dialog),FALSE,TRUE,FALSE);
	gtk_grab_add(dialog);
	gtk_widget_show_all(dialog);
	gtk_main();
}

==> vmaid-1.8.3.tar.gz: vmaid-1.8.3/src/conf.c <==
/*
    Video maid
    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#include <gdk/gdkkeysyms.h>
#include "conf.h"


/******************************************************************************
*                                                                             *
* ؿ                                                                  *
*                                                                             *
******************************************************************************/
static gint width,height;
static GtkWidget *button0,*check0,*check1,*spin0,*spin1,*spin2;
static GtkWidget *radio0,*radio1,*radio2,*radio3;


/* OKܥɽ */
#define conf_dialog_toggled conf_dialog_changed
static void conf_dialog_changed(GtkWidget *widget,gpointer user_data)
{
	gint value0,value1,value2;

	value0=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin0));
	value1=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin1));
	value2=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin2));
	gtk_widget_set_sensitive(button0,0<=value0 && value0<=10
				&& 0<value1 && value1<=width && 0<value2 && value2<=height);
}


/* OKܥ󤬲줿 */
static void conf_dialog_clicked(GtkWidget *widget,GtkWidget *dialog)
{
	gint i;
	GList *glist;
	GtkWidget *sub_menu;

	history=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin0));
	newfile=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check0));
	second=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check1));
	def_width=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin1));
	def_height=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin2));
	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio0)))
		n_pos=GTK_POS_TOP;
	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio1)))
		n_pos=GTK_POS_LEFT;
	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio2)))
		n_pos=GTK_POS_RIGHT;
	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio3)))
		n_pos=GTK_POS_BOTTOM;
	gtk_widget_destroy(dialog);
	/*  */
	sub_menu=gtk_item_factory_get_widget(item_factory_menu,"<main>/File");
	glist=gtk_container_children(GTK_CONTAINER(sub_menu));
	for (i=g_list_length(glist)-3;i>history-(history==0)+MENUFILE-2;i--)
		gtk_container_remove(GTK_CONTAINER(sub_menu),g_list_nth_data(glist,i));
	g_list_free(glist);
	/* ΡȤΰ */
	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(notebook),n_pos);
}


/* ԥܥǥ꥿󤬲줿 */
static void conf_dialog_activate(GtkWidget *widget,GtkWidget *dialog)
{
	gint value0,value1,value2;

	value0=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin0));
	value1=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin1));
	value2=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin2));
	if (0<=value0 && value0<=10
					&& 0<value1 && value1<=width && 0<value2 && value2<=height)
		conf_dialog_clicked(widget,dialog);
}


/* ESC줿 */
static gboolean conf_dialog_key_press(GtkWidget *widget,GdkEventKey *event,
															gpointer user_data)
{
	if (event->keyval==GDK_Escape)
		gtk_widget_destroy(widget);
	return FALSE;
}


void conf_dialog(void)
{
	guint key;
	GtkAccelGroup *accel;
	GtkWidget *dialog,*button1,*label0,*label1,*label2;
	GtkWidget *frame0,*frame1,*hbox0,*hbox1,*vbox;

	width=gdk_screen_width();
	height=gdk_screen_height();

	/* ᥤ󥦥ɥ */
	dialog=gtk_window_new(GTK_WINDOW_DIALOG);
	gtk_window_set_title(GTK_WINDOW(dialog),_("Configuration"));
	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
								GTK_SIGNAL_FUNC(conf_dialog_key_press),NULL);
	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
	/* 졼 */
	accel=gtk_accel_group_new();
	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
	/* ܥ */
	button0=gtk_button_new_with_label(_("OK"));
	button1=gtk_button_new_with_label(_("Cancel"));
	gtk_signal_connect(GTK_OBJECT(button0),"clicked",
												conf_dialog_clicked,dialog);
	gtk_signal_connect_object(GTK_OBJECT(button1),"clicked",
										gtk_widget_destroy,GTK_OBJECT(dialog));
	GTK_WIDGET_SET_FLAGS(button0,GTK_CAN_DEFAULT);
	GTK_WIDGET_SET_FLAGS(button1,GTK_CAN_DEFAULT);
	/* åܥ */
	check0=gtk_check_button_new_with_label(NULL);
	check1=gtk_check_button_new_with_label(NULL);
	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check0)->child),
															_("_New File"));
	gtk_widget_add_accelerator(check0,"clicked",accel,key,GDK_MOD1_MASK,0);
	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check1)->child),
															_("_Open Window"));
	gtk_widget_add_accelerator(check1,"clicked",accel,key,GDK_MOD1_MASK,0);
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check0),newfile);
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check1),second);
	gtk_signal_connect(GTK_OBJECT(check0),"toggled",conf_dialog_toggled,NULL);
	gtk_signal_connect(GTK_OBJECT(check1),"toggled",conf_dialog_toggled,NULL);
	/* ԥܥ */
	spin0=gtk_spin_button_new(
			GTK_ADJUSTMENT(gtk_adjustment_new(history,0,10,1,5,0)),0,0);
	spin1=gtk_spin_button_new(
			GTK_ADJUSTMENT(gtk_adjustment_new(def_width,0,width,1,5,0)),0,0);
	spin2=gtk_spin_button_new(
			GTK_ADJUSTMENT(gtk_adjustment_new(def_height,0,height,1,5,0)),0,0);
	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin0),TRUE);
	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin1),TRUE);
	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin2),TRUE);
	gtk_spin_button_set_shadow_type(GTK_SPIN_BUTTON(spin0),GTK_SHADOW_IN);
	gtk_spin_button_set_shadow_type(GTK_SPIN_BUTTON(spin1),GTK_SHADOW_IN);
	gtk_spin_button_set_shadow_type(GTK_SPIN_BUTTON(spin2),GTK_SHADOW_IN);
	gtk_signal_connect(GTK_OBJECT(spin0),"activate",
												conf_dialog_activate,dialog);
	gtk_signal_connect(GTK_OBJECT(spin1),"activate",
												conf_dialog_activate,dialog);
	gtk_signal_connect(GTK_OBJECT(spin2),"activate",
												conf_dialog_activate,dialog);
	gtk_signal_connect(GTK_OBJECT(spin0),"changed",conf_dialog_changed,NULL);
	gtk_signal_connect(GTK_OBJECT(spin1),"changed",conf_dialog_changed,NULL);
	gtk_signal_connect(GTK_OBJECT(spin2),"changed",conf_dialog_changed,NULL);
	/* ٥ */
	label0=gtk_label_new(NULL);
	label1=gtk_label_new(NULL);
	label2=gtk_label_new(NULL);
	key=gtk_label_parse_uline(GTK_LABEL(label0),_("H_istory"));
	gtk_widget_add_accelerator(spin0,"grab-focus",accel,key,GDK_MOD1_MASK,0);
	key=gtk_label_parse_uline(GTK_LABEL(label1),_("_Width"));
	gtk_widget_add_accelerator(spin1,"grab-focus",accel,key,GDK_MOD1_MASK,0);
	key=gtk_label_parse_uline(GTK_LABEL(label2),_("_Height"));
	gtk_widget_add_accelerator(spin2,"grab-focus",accel,key,GDK_MOD1_MASK,0);
	/* 饸ܥ */
	radio0=gtk_radio_button_new_with_label(NULL,NULL);
	radio1=gtk_radio_button_new_with_label_from_widget(
												GTK_RADIO_BUTTON(radio0),NULL);
	radio2=gtk_radio_button_new_with_label_from_widget(
												GTK_RADIO_BUTTON(radio1),NULL);
	radio3=gtk_radio_button_new_with_label_from_widget(
												GTK_RADIO_BUTTON(radio2),NULL);
	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio0)->child),_("_Top"));
	gtk_widget_add_accelerator(radio0,"clicked",accel,key,GDK_MOD1_MASK,0);
	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio1)->child),_("_Left"));
	gtk_widget_add_accelerator(radio1,"clicked",accel,key,GDK_MOD1_MASK,0);
	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio2)->child),_("_Right"));
	gtk_widget_add_accelerator(radio2,"clicked",accel,key,GDK_MOD1_MASK,0);
	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio3)->child),_("_Bottom"));
	gtk_widget_add_accelerator(radio3,"clicked",accel,key,GDK_MOD1_MASK,0);
	switch (n_pos) {
		case GTK_POS_TOP:	gtk_toggle_button_set_active(
										GTK_TOGGLE_BUTTON(radio0),TRUE);break;
		case GTK_POS_LEFT:	gtk_toggle_button_set_active(
										GTK_TOGGLE_BUTTON(radio1),TRUE);break;
		case GTK_POS_RIGHT:	gtk_toggle_button_set_active(
										GTK_TOGGLE_BUTTON(radio2),TRUE);break;
		case GTK_POS_BOTTOM:gtk_toggle_button_set_active(
										GTK_TOGGLE_BUTTON(radio3),TRUE);
	}
	gtk_signal_connect(GTK_OBJECT(radio0),"toggled",conf_dialog_toggled,NULL);
	gtk_signal_connect(GTK_OBJECT(radio1),"toggled",conf_dialog_toggled,NULL);
	gtk_signal_connect(GTK_OBJECT(radio2),"toggled",conf_dialog_toggled,NULL);
	gtk_signal_connect(GTK_OBJECT(radio3),"toggled",conf_dialog_toggled,NULL);
	/* ե졼ȥܥå */
	frame0=gtk_frame_new(_("Window Size"));
	hbox0=gtk_hbox_new(FALSE,8);
	gtk_container_set_border_width(GTK_CONTAINER(hbox0),8);
	hbox1=gtk_hbox_new(FALSE,0);
	gtk_box_pack_start(GTK_BOX(hbox1),label1,FALSE,FALSE,0);
	gtk_box_pack_start(GTK_BOX(hbox1),spin1,TRUE,TRUE,0);
	gtk_box_pack_start(GTK_BOX(hbox0),hbox1,TRUE,TRUE,0);
	hbox1=gtk_hbox_new(FALSE,0);
	gtk_box_pack_start(GTK_BOX(hbox1),label2,FALSE,FALSE,0);
	gtk_box_pack_start(GTK_BOX(hbox1),spin2,TRUE,TRUE,0);
	gtk_box_pack_start(GTK_BOX(hbox0),hbox1,TRUE,TRUE,0);
	gtk_container_add(GTK_CONTAINER(frame0),hbox0);

	frame1=gtk_frame_new(_("Tab Position"));
	vbox=gtk_vbox_new(FALSE,8);
	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
	hbox0=gtk_hbox_new(FALSE,8);
	gtk_box_pack_start(GTK_BOX(hbox0),radio0,TRUE,FALSE,0);
	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,0);
	hbox0=gtk_hbox_new(FALSE,8);
	gtk_box_pack_start(GTK_BOX(hbox0),radio1,FALSE,FALSE,0);
	gtk_box_pack_end(GTK_BOX(hbox0),radio2,FALSE,FALSE,0);
	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,0);
	hbox0=gtk_hbox_new(FALSE,0);
	gtk_box_pack_start(GTK_BOX(hbox0),radio3,TRUE,FALSE,0);
	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,0);
	gtk_container_add(GTK_CONTAINER(frame1),vbox);

	vbox=gtk_vbox_new(FALSE,8);
	hbox0=gtk_hbox_new(FALSE,0);
	gtk_box_pack_start(GTK_BOX(hbox0),label0,FALSE,FALSE,0);
	gtk_box_pack_start(GTK_BOX(hbox0),spin0,TRUE,TRUE,0);
	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,0);
	gtk_box_pack_start(GTK_BOX(vbox),check0,FALSE,FALSE,0);
	gtk_box_pack_start(GTK_BOX(vbox),check1,FALSE,FALSE,0);
	gtk_box_pack_start(GTK_BOX(vbox),frame0,FALSE,FALSE,0);

	hbox0=gtk_hbox_new(FALSE,8);
	gtk_box_pack_start(GTK_BOX(hbox0),vbox,TRUE,TRUE,0);
	gtk_box_pack_start(GTK_BOX(hbox0),frame1,TRUE,TRUE,0);

	vbox=gtk_vbox_new(FALSE,8);
	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
	gtk_box_pack_start(GTK_BOX(vbox),hbox0,TRUE,TRUE,0);
	hbox0=gtk_hbox_new(FALSE,8);
	gtk_box_pack_end(GTK_BOX(hbox0),button1,FALSE,FALSE,0);
	gtk_box_pack_end(GTK_BOX(hbox0),button0,FALSE,FALSE,0);
	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,0);
	gtk_container_add(GTK_CONTAINER(dialog),vbox);

	/* ɽ */
	gtk_widget_set_sensitive(button0,FALSE);
	gtk_widget_grab_focus(button1);

	gtk_window_set_policy(GTK_WINDOW(dialog),FALSE,TRUE,FALSE);
	gtk_grab_add(dialog);
	gtk_widget_show_all(dialog);
	gtk_main();
}
